@@ -1,4 +1,4 @@
-__all__ = ('OrderPoint', 'OrderObjectPoint', 'ResendSmsSignPoint')
+__all__ = ('OrderPoint', 'OrderObjectPoint', 'ResendSmsSignPoint', 'OrderUserIdsPoint')
 
 from expressmoney.api import *
 
@@ -56,6 +56,11 @@ class ResendSmsSignCreateContract(Contract):
     pass
 
 
+class OrderUserIdsContract(Contract):
+    id = serializers.IntegerField(min_value=1)
+    user_id = serializers.CharField(max_length=8)
+
+
 class OrderID(ID):
     _service = SERVICE
     _app = 'orders'
@@ -68,6 +73,12 @@ class ResendSmsSignPointID(ID):
     _view_set = 'resend_sms_sign'
 
 
+class OrderUserIdsID(ID):
+    _service = SERVICE
+    _app = 'orders'
+    _view_set = 'order_user_ids'
+
+
 class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = OrderID()
     _read_contract = OrderReadContract
@@ -82,3 +93,9 @@ class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
 class ResendSmsSignPoint(CreatePointMixin, ContractPoint):
     _point_id = ResendSmsSignPointID()
     _create_contract = ResendSmsSignCreateContract
+
+
+class OrderUserIdsPoint(ListPointMixin, ContractPoint):
+    _point_id = OrderUserIdsID()
+    _read_contract = OrderUserIdsContract
+    _cache_enabled = False
